==> openshift-model-operator-6.6.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeControllerManagerStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface KubeControllerManagerStatusFluent<A extends KubeControllerManagerStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,OperatorCondition item);
  public A setToConditions(Integer index,OperatorCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... items);
  public A addAllToConditions(Collection<OperatorCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... items);
  public A removeAllFromConditions(Collection<OperatorCondition> items);
  public A removeMatchingFromConditions(Predicate<OperatorConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<OperatorCondition> getConditions();
  public List<OperatorCondition> buildConditions();
  public OperatorCondition buildCondition(Integer index);
  public OperatorCondition buildFirstCondition();
  public OperatorCondition buildLastCondition();
  public OperatorCondition buildMatchingCondition(Predicate<OperatorConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<OperatorConditionBuilder> predicate);
  public A withConditions(List<OperatorCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public KubeControllerManagerStatusFluent.ConditionsNested<A> addNewCondition();
  public KubeControllerManagerStatusFluent.ConditionsNested<A> addNewConditionLike(OperatorCondition item);
  public KubeControllerManagerStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,OperatorCondition item);
  public KubeControllerManagerStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public KubeControllerManagerStatusFluent.ConditionsNested<A> editFirstCondition();
  public KubeControllerManagerStatusFluent.ConditionsNested<A> editLastCondition();
  public KubeControllerManagerStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<OperatorConditionBuilder> predicate);
  public A addToGenerations(Integer index,GenerationStatus item);
  public A setToGenerations(Integer index,GenerationStatus item);
  public A addToGenerations(io.fabric8.openshift.api.model.operator.v1.GenerationStatus... items);
  public A addAllToGenerations(Collection<GenerationStatus> items);
  public A removeFromGenerations(io.fabric8.openshift.api.model.operator.v1.GenerationStatus... items);
  public A removeAllFromGenerations(Collection<GenerationStatus> items);
  public A removeMatchingFromGenerations(Predicate<GenerationStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildGenerations instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GenerationStatus> getGenerations();
  public List<GenerationStatus> buildGenerations();
  public GenerationStatus buildGeneration(Integer index);
  public GenerationStatus buildFirstGeneration();
  public GenerationStatus buildLastGeneration();
  public GenerationStatus buildMatchingGeneration(Predicate<GenerationStatusBuilder> predicate);
  public Boolean hasMatchingGeneration(Predicate<GenerationStatusBuilder> predicate);
  public A withGenerations(List<GenerationStatus> generations);
  public A withGenerations(io.fabric8.openshift.api.model.operator.v1.GenerationStatus... generations);
  public Boolean hasGenerations();
  public KubeControllerManagerStatusFluent.GenerationsNested<A> addNewGeneration();
  public KubeControllerManagerStatusFluent.GenerationsNested<A> addNewGenerationLike(GenerationStatus item);
  public KubeControllerManagerStatusFluent.GenerationsNested<A> setNewGenerationLike(Integer index,GenerationStatus item);
  public KubeControllerManagerStatusFluent.GenerationsNested<A> editGeneration(Integer index);
  public KubeControllerManagerStatusFluent.GenerationsNested<A> editFirstGeneration();
  public KubeControllerManagerStatusFluent.GenerationsNested<A> editLastGeneration();
  public KubeControllerManagerStatusFluent.GenerationsNested<A> editMatchingGeneration(Predicate<GenerationStatusBuilder> predicate);
  public Integer getLatestAvailableRevision();
  public A withLatestAvailableRevision(Integer latestAvailableRevision);
  public Boolean hasLatestAvailableRevision();
  public String getLatestAvailableRevisionReason();
  public A withLatestAvailableRevisionReason(String latestAvailableRevisionReason);
  public Boolean hasLatestAvailableRevisionReason();
  public A addToNodeStatuses(Integer index,NodeStatus item);
  public A setToNodeStatuses(Integer index,NodeStatus item);
  public A addToNodeStatuses(io.fabric8.openshift.api.model.operator.v1.NodeStatus... items);
  public A addAllToNodeStatuses(Collection<NodeStatus> items);
  public A removeFromNodeStatuses(io.fabric8.openshift.api.model.operator.v1.NodeStatus... items);
  public A removeAllFromNodeStatuses(Collection<NodeStatus> items);
  public A removeMatchingFromNodeStatuses(Predicate<NodeStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildNodeStatuses instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NodeStatus> getNodeStatuses();
  public List<NodeStatus> buildNodeStatuses();
  public NodeStatus buildNodeStatus(Integer index);
  public NodeStatus buildFirstNodeStatus();
  public NodeStatus buildLastNodeStatus();
  public NodeStatus buildMatchingNodeStatus(Predicate<NodeStatusBuilder> predicate);
  public Boolean hasMatchingNodeStatus(Predicate<NodeStatusBuilder> predicate);
  public A withNodeStatuses(List<NodeStatus> nodeStatuses);
  public A withNodeStatuses(io.fabric8.openshift.api.model.operator.v1.NodeStatus... nodeStatuses);
  public Boolean hasNodeStatuses();
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> addNewNodeStatus();
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> addNewNodeStatusLike(NodeStatus item);
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> setNewNodeStatusLike(Integer index,NodeStatus item);
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> editNodeStatus(Integer index);
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> editFirstNodeStatus();
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> editLastNodeStatus();
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> editMatchingNodeStatus(Predicate<NodeStatusBuilder> predicate);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public Integer getReadyReplicas();
  public A withReadyReplicas(Integer readyReplicas);
  public Boolean hasReadyReplicas();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends Nested<N>,OperatorConditionFluent<KubeControllerManagerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface GenerationsNested<N> extends Nested<N>,GenerationStatusFluent<KubeControllerManagerStatusFluent.GenerationsNested<N>>{
    public N and();
    public N endGeneration();
    
  }
  public interface NodeStatusesNested<N> extends Nested<N>,NodeStatusFluent<KubeControllerManagerStatusFluent.NodeStatusesNested<N>>{
    public N and();
    public N endNodeStatus();
    
  }
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeControllerManagerStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface KubeControllerManagerStatusFluent<A extends KubeControllerManagerStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,OperatorCondition item);
  public A setToConditions(int index,OperatorCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... items);
  public A addAllToConditions(Collection<OperatorCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... items);
  public A removeAllFromConditions(Collection<OperatorCondition> items);
  public A removeMatchingFromConditions(Predicate<OperatorConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<OperatorCondition> getConditions();
  public List<OperatorCondition> buildConditions();
  public OperatorCondition buildCondition(int index);
  public OperatorCondition buildFirstCondition();
  public OperatorCondition buildLastCondition();
  public OperatorCondition buildMatchingCondition(Predicate<OperatorConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<OperatorConditionBuilder> predicate);
  public A withConditions(List<OperatorCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public KubeControllerManagerStatusFluent.ConditionsNested<A> addNewCondition();
  public KubeControllerManagerStatusFluent.ConditionsNested<A> addNewConditionLike(OperatorCondition item);
  public KubeControllerManagerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,OperatorCondition item);
  public KubeControllerManagerStatusFluent.ConditionsNested<A> editCondition(int index);
  public KubeControllerManagerStatusFluent.ConditionsNested<A> editFirstCondition();
  public KubeControllerManagerStatusFluent.ConditionsNested<A> editLastCondition();
  public KubeControllerManagerStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<OperatorConditionBuilder> predicate);
  public A addToGenerations(int index,GenerationStatus item);
  public A setToGenerations(int index,GenerationStatus item);
  public A addToGenerations(io.fabric8.openshift.api.model.operator.v1.GenerationStatus... items);
  public A addAllToGenerations(Collection<GenerationStatus> items);
  public A removeFromGenerations(io.fabric8.openshift.api.model.operator.v1.GenerationStatus... items);
  public A removeAllFromGenerations(Collection<GenerationStatus> items);
  public A removeMatchingFromGenerations(Predicate<GenerationStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildGenerations instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GenerationStatus> getGenerations();
  public List<GenerationStatus> buildGenerations();
  public GenerationStatus buildGeneration(int index);
  public GenerationStatus buildFirstGeneration();
  public GenerationStatus buildLastGeneration();
  public GenerationStatus buildMatchingGeneration(Predicate<GenerationStatusBuilder> predicate);
  public Boolean hasMatchingGeneration(Predicate<GenerationStatusBuilder> predicate);
  public A withGenerations(List<GenerationStatus> generations);
  public A withGenerations(io.fabric8.openshift.api.model.operator.v1.GenerationStatus... generations);
  public Boolean hasGenerations();
  public KubeControllerManagerStatusFluent.GenerationsNested<A> addNewGeneration();
  public KubeControllerManagerStatusFluent.GenerationsNested<A> addNewGenerationLike(GenerationStatus item);
  public KubeControllerManagerStatusFluent.GenerationsNested<A> setNewGenerationLike(int index,GenerationStatus item);
  public KubeControllerManagerStatusFluent.GenerationsNested<A> editGeneration(int index);
  public KubeControllerManagerStatusFluent.GenerationsNested<A> editFirstGeneration();
  public KubeControllerManagerStatusFluent.GenerationsNested<A> editLastGeneration();
  public KubeControllerManagerStatusFluent.GenerationsNested<A> editMatchingGeneration(Predicate<GenerationStatusBuilder> predicate);
  public Integer getLatestAvailableRevision();
  public A withLatestAvailableRevision(Integer latestAvailableRevision);
  public Boolean hasLatestAvailableRevision();
  public String getLatestAvailableRevisionReason();
  public A withLatestAvailableRevisionReason(String latestAvailableRevisionReason);
  public Boolean hasLatestAvailableRevisionReason();
  public A addToNodeStatuses(int index,NodeStatus item);
  public A setToNodeStatuses(int index,NodeStatus item);
  public A addToNodeStatuses(io.fabric8.openshift.api.model.operator.v1.NodeStatus... items);
  public A addAllToNodeStatuses(Collection<NodeStatus> items);
  public A removeFromNodeStatuses(io.fabric8.openshift.api.model.operator.v1.NodeStatus... items);
  public A removeAllFromNodeStatuses(Collection<NodeStatus> items);
  public A removeMatchingFromNodeStatuses(Predicate<NodeStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildNodeStatuses instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NodeStatus> getNodeStatuses();
  public List<NodeStatus> buildNodeStatuses();
  public NodeStatus buildNodeStatus(int index);
  public NodeStatus buildFirstNodeStatus();
  public NodeStatus buildLastNodeStatus();
  public NodeStatus buildMatchingNodeStatus(Predicate<NodeStatusBuilder> predicate);
  public Boolean hasMatchingNodeStatus(Predicate<NodeStatusBuilder> predicate);
  public A withNodeStatuses(List<NodeStatus> nodeStatuses);
  public A withNodeStatuses(io.fabric8.openshift.api.model.operator.v1.NodeStatus... nodeStatuses);
  public Boolean hasNodeStatuses();
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> addNewNodeStatus();
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> addNewNodeStatusLike(NodeStatus item);
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> setNewNodeStatusLike(int index,NodeStatus item);
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> editNodeStatus(int index);
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> editFirstNodeStatus();
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> editLastNodeStatus();
  public KubeControllerManagerStatusFluent.NodeStatusesNested<A> editMatchingNodeStatus(Predicate<NodeStatusBuilder> predicate);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public Integer getReadyReplicas();
  public A withReadyReplicas(Integer readyReplicas);
  public Boolean hasReadyReplicas();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends Nested<N>,OperatorConditionFluent<KubeControllerManagerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface GenerationsNested<N> extends Nested<N>,GenerationStatusFluent<KubeControllerManagerStatusFluent.GenerationsNested<N>>{
    public N and();
    public N endGeneration();
    
  }
  public interface NodeStatusesNested<N> extends Nested<N>,NodeStatusFluent<KubeControllerManagerStatusFluent.NodeStatusesNested<N>>{
    public N and();
    public N endNodeStatus();
    
  }
  
}
